# Examples

This directory contains all the notebooks built as part of the
[holoviews.org](http://holoviews.org) website.

## Directory structure

* ``assets``: Files used by the examples.
* ``gallery``: Examples shown on the [gallery page](http://holoviews.org/gallery/index.html).
* ``getting_started``: Notebooks used in the [getting started](http://holoviews.org/getting_started/index.html) guide.
* `reference`: Notebooks shown in the website [reference gallery](http://holoviews.org/reference/index.html)
* ``topics``: Notebooks shown in the [showcase](http://holoviews.org/reference/showcase/index.html)
* ``user_guide``: Notebooks used in the [user guide](http://holoviews.org/user_guide/index.html).

## Contributing to examples

If you have improvements to suggest regarding the existing set of
notebooks, please tell us on [gitter](https://gitter.im/ioam/holoviews)
or submit a pull request. We are happy to consider user submissions for
``/topics`` so if you have an interesting notebook using HoloViews that
isn't too long and about a domain not already in ``/topics``, please
consider submitting a PR.

Lastly, if you find a particular notebook that does not seem to be
working, please file an
[issue](https://github.com/ioam/holoviews/issues).
